==> almond_0.3.1+dfsg.orig.tar.xz: almond-0.3.1+dfsg/tests/all.js <==

doh.registerUrl("simple", "../simple.html");
doh.registerUrl("defineDouble", "../defineDouble/defineDouble.html");
doh.registerUrl("moduleConfig", "../moduleConfig/moduleConfig.html");
doh.registerUrl("mapConfig", "../mapConfig/mapConfig.html");
doh.registerUrl("mapConfigStar", "../mapConfig/mapConfigStar.html");
doh.registerUrl("mapConfigStarAdapter", "../mapConfig/mapConfigStarAdapter.html");
doh.registerUrl("mapConfigSpecificity", "../mapConfig/mapConfigSpecificity.html");
doh.registerUrl("mapConfigPlugin", "../mapConfig/mapConfigPlugin.html");
doh.registerUrl("plugins", "../plugins/plugins.html");
doh.registerUrl("pluginsMapSameName", "../plugins/pluginMapSameName/pluginMapSameName.html");
doh.registerUrl("orderPlugin", "../plugins/order/order.html");
doh.registerUrl("text", "../plugins/text.html");
doh.registerUrl("coffee", "../plugins/coffee.html");
doh.registerUrl("shim", "../shim/shim.html");
doh.registerUrl("unorderedSeparate", "../unordered/separate.html");
doh.registerUrl("emptyFactory", "../emptyFactory/emptyFactory.html");
doh.registerUrl("missing", "../missing/missing.html");
doh.registerUrl("insertRequire", "../insertRequire/insertRequire.html", 4000);
doh.registerUrl("circular", "../circular/circular.html");
doh.registerUrl("circular414", "../circular/414/414.html");
doh.registerUrl("circularTranspiler", "../circular/transpiler/transpiler.html");
doh.registerUrl("relativePaths", "../relativePaths/relativePaths.html");
doh.registerUrl("errback", "../errback/errback.html");
doh.registerUrl("specialDeps", "../specialDeps/specialDeps.html");
doh.registerUrl("hasOwnPropertyTests", "../hasOwnProperty/hasOwnProperty.html");
doh.registerUrl("firstDefine", "../firstDefine/firstDefine.html");
doh.registerUrl("topRelativeRequire", "../topRelativeRequire/topRelativeRequire.html");
doh.registerUrl("configDeps", "../configDeps/configDeps.html");
doh.registerUrl("defineNoCallback", "../defineNoCallback/defineNoCallback.html");
doh.registerUrl("packagesNode", "../packagesNode/packagesNode.html");
doh.registerUrl("requireInDefine", "../requireInDefine/requireInDefine.html");
doh.registerUrl("badAnonDefine", "../badAnonDefine/badAnonDefine.html");

==> almond_0.3.3+dfsg.orig.tar.xz: almond-0.3.3+dfsg/tests/all.js <==

doh.registerUrl("simple", "../simple.html");
doh.registerUrl("defineDouble", "../defineDouble/defineDouble.html");
doh.registerUrl("moduleConfig", "../moduleConfig/moduleConfig.html");
doh.registerUrl("mapConfig", "../mapConfig/mapConfig.html");
doh.registerUrl("mapConfigStar", "../mapConfig/mapConfigStar.html");
doh.registerUrl("mapConfigStarAdapter", "../mapConfig/mapConfigStarAdapter.html");
doh.registerUrl("mapConfigSpecificity", "../mapConfig/mapConfigSpecificity.html");
doh.registerUrl("mapConfigPlugin", "../mapConfig/mapConfigPlugin.html");
doh.registerUrl("plugins", "../plugins/plugins.html");
doh.registerUrl("pluginRelative", "../plugins/relative/pluginRelative.html");
doh.registerUrl("pluginsMapSameName", "../plugins/pluginMapSameName/pluginMapSameName.html");
doh.registerUrl("orderPlugin", "../plugins/order/order.html");
doh.registerUrl("text", "../plugins/text.html");
doh.registerUrl("coffee", "../plugins/coffee.html");
doh.registerUrl("shim", "../shim/shim.html");
doh.registerUrl("unorderedSeparate", "../unordered/separate.html");
doh.registerUrl("emptyFactory", "../emptyFactory/emptyFactory.html");
doh.registerUrl("missing", "../missing/missing.html");
doh.registerUrl("insertRequire", "../insertRequire/insertRequire.html", 4000);
doh.registerUrl("circular", "../circular/circular.html");
doh.registerUrl("circular414", "../circular/414/414.html");
doh.registerUrl("circularTranspiler", "../circular/transpiler/transpiler.html");
doh.registerUrl("relativePaths", "../relativePaths/relativePaths.html");
doh.registerUrl("errback", "../errback/errback.html");
doh.registerUrl("specialDeps", "../specialDeps/specialDeps.html");
doh.registerUrl("hasOwnPropertyTests", "../hasOwnProperty/hasOwnProperty.html");
doh.registerUrl("firstDefine", "../firstDefine/firstDefine.html");
doh.registerUrl("relativeId", "../relativeId/relativeId.html");
doh.registerUrl("topRelativeRequire", "../topRelativeRequire/topRelativeRequire.html");
doh.registerUrl("configDeps", "../configDeps/configDeps.html");
doh.registerUrl("defineNoCallback", "../defineNoCallback/defineNoCallback.html");
doh.registerUrl("packagesNode", "../packagesNode/packagesNode.html");
doh.registerUrl("requireInDefine", "../requireInDefine/requireInDefine.html");
doh.registerUrl("badAnonDefine", "../badAnonDefine/badAnonDefine.html");
